<?php

/**
 * @file
 * Xero page callbacks.
 */

/**
 * Xero Authorization page callback.
 */
function xero_authorize($encoded_params = NULL) {
  global $user;

  $provided_params = NULL;
  if ($encoded_params) {
    $raw_provided_params = urldecode($encoded_params);
    $provided_params = drupal_get_query_array($raw_provided_params);
  }

  // Gets the query parameters.
  $query_params = drupal_get_query_parameters($provided_params);
  $code = isset($query_params['code']) ? $query_params['code'] : '';
  $state = isset($query_params['state']) ? $query_params['state'] : '';
  $destination = drupal_get_destination();
  $route = isset($destination['destination']) ? $destination['destination'] : '<front>';
  $stored_state = variable_get('xero_temporary_state', NULL);

  if ($state === $stored_state) {
    try {
      $provider = new XeroProvider([
        'clientId' => variable_get('xero_consumer_key', ''),
        'clientSecret' => variable_get('xero_consumer_secret', ''),
        'redirectUri' => url('xero/authorize', ['absolute' => TRUE]),
      ]);

      $token = $provider->getAccessToken('authorization_code', ['code' => $code]);
      if (!empty($token)) {
        variable_set('xero_global_token', serialize($token));
        module_invoke_all('xero_authorize', $user, $token);

        drupal_set_message(t('Sucessfully authorized to xero.'));
      }
      else {
        drupal_set_message(t('An error occurred authorizing with xero.'), 'error');
      }
    }
    catch (Exception $e) {
      watchdog_exception('xero', $e, 'An error occurred getting the access token');
      drupal_set_message(t('An access token could not be exchanged.'), 'error');
    }
  }
  else {
    drupal_set_message(t('The cross-site request forgery token returned from Xero did not match.'), 'error');
  }

  // Clean up temporary state.
  variable_del('xero_temporary_state');

  // Redirects to the appropriate page.
  return '';
  // drupal_goto($route);
}

/**
 * Xero Autocomplete page callback.
 *
 * @param array $type
 *   The xero data type array.
 * @param string $string
 *   The string to search for.
 */
function xero_autocomplete($type, $string = '') {
  $matches = array();
  $items = xero_get_cache($type['plural']);
  $guid_key = $type['guid'];
  $label_key = !empty($type['label']) ? $type['label'] : $type['guid'];

  foreach ($items[$type['name']] as $item) {
    if (!empty($string) && is_string(stristr($item[$label_key], $string))) {
      $id = $item[$guid_key];
      $matches[$id . ' (' . $item[$label_key] . ')'] = check_plain($item[$label_key]);
    }
  }

  drupal_json_output($matches);
}
